@@ -479,7 +479,7 @@ MagickExport const ConfigureInfo **GetConfigureInfoList(const char *pattern,
   }
   UnlockSemaphoreInfo(configure_semaphore);
   if (i == 0)
-    options=(const ConfigureInfo **) RelinquishMagickMemory(options);
+    options=(const ConfigureInfo **) RelinquishMagickMemory((void*) options);
   else
     {
       qsort((void *) options,(size_t) i,sizeof(*options),ConfigureInfoCompare);
@@ -1245,8 +1245,8 @@ static MagickBooleanType LoadConfigureCache(LinkedListInfo *cache,
                   file_xml=FileToXML(path,~0UL);
                   if (file_xml != (char *) NULL)
                     {
-                      status&=LoadConfigureCache(cache,file_xml,path,depth+1,
-                        exception);
+                      status&=(MagickStatusType) LoadConfigureCache(cache,
+                        file_xml,path,depth+1,exception);
                       file_xml=DestroyString(file_xml);
                     }
                 }
