@@ -19,7 +19,7 @@
 %                                 July 2009                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright @ 2009 ImageMagick Studio LLC, a non-profit organization         %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -61,11 +61,12 @@
 #include "MagickCore/resource_.h"
 #include "MagickCore/string-private.h"
 #include "MagickCore/thread-private.h"
-#if defined(MAGICKCORE_FFTW_DELEGATE)
+#if defined(MAGICKCORE_FFTW_DELEGATE) && !defined(__cplusplus) && !defined(c_plusplus)
 #if defined(MAGICKCORE_HAVE_COMPLEX_H)
 #include <complex.h>
 #endif
 #include <fftw3.h>
+#if !defined(MAGICKCORE_CHANNEL_MASK_DEPTH)
 #if !defined(MAGICKCORE_HAVE_CABS)
 #define cabs(z)  (sqrt(z[0]*z[0]+z[1]*z[1]))
 #endif
@@ -79,6 +80,7 @@
 #define creal(z)  (z[0])
 #endif
 #endif
+#endif
 
 /*
   Typedef declarations.
@@ -173,10 +175,10 @@ MagickExport Image *ComplexImages(const Image *images,const ComplexOperator op,
 
   assert(images != (Image *) NULL);
   assert(images->signature == MagickCoreSignature);
-  if (images->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",images->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",images->filename);
   if (images->next == (Image *) NULL)
     {
       (void) ThrowMagickException(exception,GetMagickModule(),ImageError,
@@ -278,60 +280,65 @@ MagickExport Image *ComplexImages(const Image *images,const ComplexOperator op,
     {
       ssize_t
         i;
-
+      
       for (i=0; i < (ssize_t) number_channels; i++)
       {
+        double
+          ai = QuantumScale*(double) Ai[i],
+          ar = QuantumScale*(double) Ar[i],
+          bi = QuantumScale*(double) Bi[i],
+          br = QuantumScale*(double) Br[i],
+          ci,
+          cr;
+
         switch (op)
         {
           case AddComplexOperator:
           {
-            Cr[i]=Ar[i]+Br[i];
-            Ci[i]=Ai[i]+Bi[i];
+            cr=ar+br;
+            ci=ai+bi;
             break;
           }
           case ConjugateComplexOperator:
           default:
           {
-            Cr[i]=Ar[i];
-            Ci[i]=(-Ai[i]);
+            cr=ar;
+            ci=(-ai);
             break;
           }
           case DivideComplexOperator:
           {
-            double
-              gamma;
-
-            gamma=QuantumRange*PerceptibleReciprocal(QuantumScale*Br[i]*Br[i]+
-              QuantumScale*Bi[i]*Bi[i]+snr);
-            Cr[i]=gamma*(QuantumScale*Ar[i]*Br[i]+QuantumScale*Ai[i]*Bi[i]);
-            Ci[i]=gamma*(QuantumScale*Ai[i]*Br[i]-QuantumScale*Ar[i]*Bi[i]);
+            cr=PerceptibleReciprocal(br*br+bi*bi+snr)*(ar*br+ai*bi);
+            ci=PerceptibleReciprocal(br*br+bi*bi+snr)*(ai*br-ar*bi);
             break;
           }
           case MagnitudePhaseComplexOperator:
           {
-            Cr[i]=sqrt(QuantumScale*Ar[i]*Ar[i]+QuantumScale*Ai[i]*Ai[i]);
-            Ci[i]=atan2((double) Ai[i],(double) Ar[i])/(2.0*MagickPI)+0.5;
+            cr=sqrt(ar*ar+ai*ai);
+            ci=atan2((double) ai,(double) ar)/(2.0*MagickPI)+0.5;
             break;
           }
           case MultiplyComplexOperator:
           {
-            Cr[i]=(QuantumScale*Ar[i]*Br[i]-QuantumScale*Ai[i]*Bi[i]);
-            Ci[i]=(QuantumScale*Ai[i]*Br[i]+QuantumScale*Ar[i]*Bi[i]);
+            cr=(ar*br-ai*bi);
+            ci=(ai*br+ar*bi);
             break;
           }
           case RealImaginaryComplexOperator:
           {
-            Cr[i]=Ar[i]*cos(2.0*MagickPI*(Ai[i]-0.5));
-            Ci[i]=Ar[i]*sin(2.0*MagickPI*(Ai[i]-0.5));
+            cr=ar*cos(2.0*MagickPI*(ai-0.5));
+            ci=ar*sin(2.0*MagickPI*(ai-0.5));
             break;
           }
           case SubtractComplexOperator:
           {
-            Cr[i]=Ar[i]-Br[i];
-            Ci[i]=Ai[i]-Bi[i];
+            cr=ar-br;
+            ci=ai-bi;
             break;
           }
         }
+        Cr[i]=(double) QuantumRange*cr;
+        Ci[i]=(double) QuantumRange*ci;
       }
       Ar+=GetPixelChannels(Ar_image);
       Ai+=GetPixelChannels(Ai_image);
@@ -384,7 +391,7 @@ MagickExport Image *ComplexImages(const Image *images,const ComplexOperator op,
 %  (DFT) of the image either as a magnitude / phase or real / imaginary image
 %  pair.
 %
-%  The format of the ForwadFourierTransformImage method is:
+%  The format of the ForwardFourierTransformImage method is:
 %
 %      Image *ForwardFourierTransformImage(const Image *image,
 %        const MagickBooleanType modulus,ExceptionInfo *exception)
@@ -400,7 +407,7 @@ MagickExport Image *ComplexImages(const Image *images,const ComplexOperator op,
 %
 */
 
-#if defined(MAGICKCORE_FFTW_DELEGATE)
+#if defined(MAGICKCORE_FFTW_DELEGATE) && !defined(__cplusplus) && !defined(c_plusplus)
 
 static MagickBooleanType RollFourier(const size_t width,const size_t height,
   const ssize_t x_offset,const ssize_t y_offset,double *roll_pixels)
@@ -413,11 +420,9 @@ static MagickBooleanType RollFourier(const size_t width,const size_t height,
 
   ssize_t
     i,
-    x;
-
-  ssize_t
     u,
     v,
+    x,
     y;
 
   /*
@@ -442,7 +447,7 @@ static MagickBooleanType RollFourier(const size_t width,const size_t height,
       else
         u=((x+x_offset) > ((ssize_t) width-1L)) ? x+x_offset-(ssize_t) width :
           x+x_offset;
-      source_pixels[v*width+u]=roll_pixels[i++];
+      source_pixels[v*(ssize_t) width+u]=roll_pixels[i++];
     }
   }
   (void) memcpy(roll_pixels,source_pixels,height*width*sizeof(*source_pixels));
@@ -456,11 +461,9 @@ static MagickBooleanType ForwardQuadrantSwap(const size_t width,
   MagickBooleanType
     status;
 
-  ssize_t
-    x;
-
   ssize_t
     center,
+    x,
     y;
 
   /*
@@ -473,13 +476,14 @@ static MagickBooleanType ForwardQuadrantSwap(const size_t width,
     return(MagickFalse);
   for (y=0L; y < (ssize_t) height; y++)
     for (x=0L; x < (ssize_t) (width/2L); x++)
-      forward_pixels[y*width+x+width/2L]=source_pixels[y*center+x];
+      forward_pixels[y*(ssize_t) width+x+(ssize_t) width/2L]=
+        source_pixels[y*center+x];
   for (y=1; y < (ssize_t) height; y++)
     for (x=0L; x < (ssize_t) (width/2L); x++)
-      forward_pixels[(height-y)*width+width/2L-x-1L]=
+      forward_pixels[((ssize_t) height-y)*(ssize_t) width+(ssize_t) width/2L-x-1L]=
         source_pixels[y*center+x+1L];
   for (x=0L; x < (ssize_t) (width/2L); x++)
-    forward_pixels[width/2L-x-1L]=source_pixels[x+1L];
+    forward_pixels[(ssize_t) width/2L-x-1L]=source_pixels[x+1L];
   return(MagickTrue);
 }
 
@@ -487,14 +491,12 @@ static void CorrectPhaseLHS(const size_t width,const size_t height,
   double *fourier_pixels)
 {
   ssize_t
-    x;
-
-  ssize_t
+    x,
     y;
 
   for (y=0L; y < (ssize_t) height; y++)
     for (x=0L; x < (ssize_t) (width/2L); x++)
-      fourier_pixels[y*width+x]*=(-1.0);
+      fourier_pixels[y*(ssize_t) width+x]*=(-1.0);
 }
 
 static MagickBooleanType ForwardFourier(const FourierInfo *fourier_info,
@@ -522,11 +524,9 @@ static MagickBooleanType ForwardFourier(const FourierInfo *fourier_info,
   Quantum
     *q;
 
-  ssize_t
-    x;
-
   ssize_t
     i,
+    x,
     y;
 
   magnitude_image=GetFirstImageInList(image);
@@ -540,10 +540,10 @@ static MagickBooleanType ForwardFourier(const FourierInfo *fourier_info,
   /*
     Create "Fourier Transform" image from constituent arrays.
   */
-  magnitude_info=AcquireVirtualMemory((size_t) fourier_info->width,
-    fourier_info->height*sizeof(*magnitude_pixels));
-  phase_info=AcquireVirtualMemory((size_t) fourier_info->width,
-    fourier_info->height*sizeof(*phase_pixels));
+  magnitude_info=AcquireVirtualMemory(fourier_info->width,fourier_info->height*
+    sizeof(*magnitude_pixels));
+  phase_info=AcquireVirtualMemory(fourier_info->width,fourier_info->height*
+    sizeof(*phase_pixels));
   if ((magnitude_info == (MemoryInfo *) NULL) ||
       (phase_info == (MemoryInfo *) NULL))
     {
@@ -593,31 +593,31 @@ static MagickBooleanType ForwardFourier(const FourierInfo *fourier_info,
         case RedPixelChannel:
         default:
         {
-          SetPixelRed(magnitude_image,ClampToQuantum(QuantumRange*
+          SetPixelRed(magnitude_image,ClampToQuantum((double) QuantumRange*
             magnitude_pixels[i]),q);
           break;
         }
         case GreenPixelChannel:
         {
-          SetPixelGreen(magnitude_image,ClampToQuantum(QuantumRange*
+          SetPixelGreen(magnitude_image,ClampToQuantum((double) QuantumRange*
             magnitude_pixels[i]),q);
           break;
         }
         case BluePixelChannel:
         {
-          SetPixelBlue(magnitude_image,ClampToQuantum(QuantumRange*
+          SetPixelBlue(magnitude_image,ClampToQuantum((double) QuantumRange*
             magnitude_pixels[i]),q);
           break;
         }
         case BlackPixelChannel:
         {
-          SetPixelBlack(magnitude_image,ClampToQuantum(QuantumRange*
+          SetPixelBlack(magnitude_image,ClampToQuantum((double) QuantumRange*
             magnitude_pixels[i]),q);
           break;
         }
         case AlphaPixelChannel:
         {
-          SetPixelAlpha(magnitude_image,ClampToQuantum(QuantumRange*
+          SetPixelAlpha(magnitude_image,ClampToQuantum((double) QuantumRange*
             magnitude_pixels[i]),q);
           break;
         }
@@ -645,31 +645,31 @@ static MagickBooleanType ForwardFourier(const FourierInfo *fourier_info,
         case RedPixelChannel:
         default:
         {
-          SetPixelRed(phase_image,ClampToQuantum(QuantumRange*
+          SetPixelRed(phase_image,ClampToQuantum((double) QuantumRange*
             phase_pixels[i]),q);
           break;
         }
         case GreenPixelChannel:
         {
-          SetPixelGreen(phase_image,ClampToQuantum(QuantumRange*
+          SetPixelGreen(phase_image,ClampToQuantum((double) QuantumRange*
             phase_pixels[i]),q);
           break;
         }
         case BluePixelChannel:
         {
-          SetPixelBlue(phase_image,ClampToQuantum(QuantumRange*
+          SetPixelBlue(phase_image,ClampToQuantum((double) QuantumRange*
             phase_pixels[i]),q);
           break;
         }
         case BlackPixelChannel:
         {
-          SetPixelBlack(phase_image,ClampToQuantum(QuantumRange*
+          SetPixelBlack(phase_image,ClampToQuantum((double) QuantumRange*
             phase_pixels[i]),q);
           break;
         }
         case AlphaPixelChannel:
         {
-          SetPixelAlpha(phase_image,ClampToQuantum(QuantumRange*
+          SetPixelAlpha(phase_image,ClampToQuantum((double) QuantumRange*
             phase_pixels[i]),q);
           break;
         }
@@ -697,6 +697,9 @@ static MagickBooleanType ForwardFourierTransform(FourierInfo *fourier_info,
   const char
     *value;
 
+  const Quantum
+    *p;
+
   double
     *source_pixels;
 
@@ -710,21 +713,22 @@ static MagickBooleanType ForwardFourierTransform(FourierInfo *fourier_info,
     *forward_info,
     *source_info;
 
-  const Quantum
-    *p;
-
   ssize_t
     i,
-    x;
-
-  ssize_t
+    x,
     y;
 
   /*
     Generate the forward Fourier transform.
   */
-  source_info=AcquireVirtualMemory((size_t) fourier_info->width,
-    fourier_info->height*sizeof(*source_pixels));
+  if ((fourier_info->width >= INT_MAX) || (fourier_info->height >= INT_MAX))
+    {
+      (void) ThrowMagickException(exception,GetMagickModule(),ImageError,
+        "WidthOrHeightExceedsLimit","`%s'",image->filename);
+      return(MagickFalse);
+    }
+  source_info=AcquireVirtualMemory(fourier_info->width,fourier_info->height*
+    sizeof(*source_pixels));
   if (source_info == (MemoryInfo *) NULL)
     {
       (void) ThrowMagickException(exception,GetMagickModule(),
@@ -749,27 +753,27 @@ static MagickBooleanType ForwardFourierTransform(FourierInfo *fourier_info,
         case RedPixelChannel:
         default:
         {
-          source_pixels[i]=QuantumScale*GetPixelRed(image,p);
+          source_pixels[i]=QuantumScale*(double) GetPixelRed(image,p);
           break;
         }
         case GreenPixelChannel:
         {
-          source_pixels[i]=QuantumScale*GetPixelGreen(image,p);
+          source_pixels[i]=QuantumScale*(double) GetPixelGreen(image,p);
           break;
         }
         case BluePixelChannel:
         {
-          source_pixels[i]=QuantumScale*GetPixelBlue(image,p);
+          source_pixels[i]=QuantumScale*(double) GetPixelBlue(image,p);
           break;
         }
         case BlackPixelChannel:
         {
-          source_pixels[i]=QuantumScale*GetPixelBlack(image,p);
+          source_pixels[i]=QuantumScale*(double) GetPixelBlack(image,p);
           break;
         }
         case AlphaPixelChannel:
         {
-          source_pixels[i]=QuantumScale*GetPixelAlpha(image,p);
+          source_pixels[i]=QuantumScale*(double) GetPixelAlpha(image,p);
           break;
         }
       }
@@ -778,8 +782,8 @@ static MagickBooleanType ForwardFourierTransform(FourierInfo *fourier_info,
     }
   }
   image_view=DestroyCacheView(image_view);
-  forward_info=AcquireVirtualMemory((size_t) fourier_info->width,
-    (fourier_info->height/2+1)*sizeof(*forward_pixels));
+  forward_info=AcquireVirtualMemory(fourier_info->width,(fourier_info->height/2+
+    1)*sizeof(*forward_pixels));
   if (forward_info == (MemoryInfo *) NULL)
     {
       (void) ThrowMagickException(exception,GetMagickModule(),
@@ -791,8 +795,8 @@ static MagickBooleanType ForwardFourierTransform(FourierInfo *fourier_info,
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
   #pragma omp critical (MagickCore_ForwardFourierTransform)
 #endif
-  fftw_r2c_plan=fftw_plan_dft_r2c_2d(fourier_info->width,fourier_info->height,
-    source_pixels,forward_pixels,FFTW_ESTIMATE);
+  fftw_r2c_plan=fftw_plan_dft_r2c_2d((int) fourier_info->width,
+    (int) fourier_info->height,source_pixels,forward_pixels,FFTW_ESTIMATE);
   fftw_execute_dft_r2c(fftw_r2c_plan,source_pixels,forward_pixels);
   fftw_destroy_plan(fftw_r2c_plan);
   source_info=(MemoryInfo *) RelinquishVirtualMemory(source_info);
@@ -874,10 +878,10 @@ static MagickBooleanType ForwardFourierTransformChannel(const Image *image,
   fourier_info.center=(ssize_t) (fourier_info.width/2L)+1L;
   fourier_info.channel=channel;
   fourier_info.modulus=modulus;
-  magnitude_info=AcquireVirtualMemory((size_t) fourier_info.width,
-    (fourier_info.height/2+1)*sizeof(*magnitude_pixels));
-  phase_info=AcquireVirtualMemory((size_t) fourier_info.width,
-    (fourier_info.height/2+1)*sizeof(*phase_pixels));
+  magnitude_info=AcquireVirtualMemory(fourier_info.width,(fourier_info.height/2+
+    1)*sizeof(*magnitude_pixels));
+  phase_info=AcquireVirtualMemory(fourier_info.width,(fourier_info.height/2+1)*
+    sizeof(*phase_pixels));
   if ((magnitude_info == (MemoryInfo *) NULL) ||
       (phase_info == (MemoryInfo *) NULL))
     {
@@ -909,7 +913,7 @@ MagickExport Image *ForwardFourierTransformImage(const Image *image,
     *fourier_image;
 
   fourier_image=NewImageList();
-#if !defined(MAGICKCORE_FFTW_DELEGATE)
+#if !defined(MAGICKCORE_FFTW_DELEGATE) || defined(__cplusplus) || defined(c_plusplus)
   (void) modulus;
   (void) ThrowMagickException(exception,GetMagickModule(),
     MissingDelegateWarning,"DelegateLibrarySupportNotBuiltIn","`%s' (FFTW)",
@@ -1077,15 +1081,13 @@ MagickExport Image *ForwardFourierTransformImage(const Image *image,
 %
 */
 
-#if defined(MAGICKCORE_FFTW_DELEGATE)
+#if defined(MAGICKCORE_FFTW_DELEGATE) && !defined(__cplusplus) && !defined(c_plusplus)
 static MagickBooleanType InverseQuadrantSwap(const size_t width,
   const size_t height,const double *source,double *destination)
 {
-  ssize_t
-    x;
-
   ssize_t
     center,
+    x,
     y;
 
   /*
@@ -1094,12 +1096,13 @@ static MagickBooleanType InverseQuadrantSwap(const size_t width,
   center=(ssize_t) (width/2L)+1L;
   for (y=1L; y < (ssize_t) height; y++)
     for (x=0L; x < (ssize_t) (width/2L+1L); x++)
-      destination[(height-y)*center-x+width/2L]=source[y*width+x];
+      destination[((ssize_t) height-y)*center-x+(ssize_t) width/2L]=
+        source[y*(ssize_t) width+x];
   for (y=0L; y < (ssize_t) height; y++)
-    destination[y*center]=source[y*width+width/2L];
+    destination[y*center]=source[y*(ssize_t) width+(ssize_t) width/2L];
   for (x=0L; x < center; x++)
     destination[x]=source[center-x-1L];
-  return(RollFourier(center,height,0L,(ssize_t) height/-2L,destination));
+  return(RollFourier((size_t) center,height,0L,(ssize_t) height/-2L,destination));
 }
 
 static MagickBooleanType InverseFourier(FourierInfo *fourier_info,
@@ -1110,6 +1113,9 @@ static MagickBooleanType InverseFourier(FourierInfo *fourier_info,
     *magnitude_view,
     *phase_view;
 
+  const Quantum
+    *p;
+
   double
     *inverse_pixels,
     *magnitude_pixels,
@@ -1123,25 +1129,20 @@ static MagickBooleanType InverseFourier(FourierInfo *fourier_info,
     *magnitude_info,
     *phase_info;
 
-  const Quantum
-    *p;
-
   ssize_t
     i,
-    x;
-
-  ssize_t
+    x,
     y;
 
   /*
     Inverse fourier - read image and break down into a double array.
   */
-  magnitude_info=AcquireVirtualMemory((size_t) fourier_info->width,
-    fourier_info->height*sizeof(*magnitude_pixels));
-  phase_info=AcquireVirtualMemory((size_t) fourier_info->width,
-    fourier_info->height*sizeof(*phase_pixels));
-  inverse_info=AcquireVirtualMemory((size_t) fourier_info->width,
-    (fourier_info->height/2+1)*sizeof(*inverse_pixels));
+  magnitude_info=AcquireVirtualMemory(fourier_info->width,fourier_info->height*
+    sizeof(*magnitude_pixels));
+  phase_info=AcquireVirtualMemory(fourier_info->width,fourier_info->height*
+    sizeof(*phase_pixels));
+  inverse_info=AcquireVirtualMemory(fourier_info->width,(fourier_info->height/2+
+    1)*sizeof(*inverse_pixels));
   if ((magnitude_info == (MemoryInfo *) NULL) ||
       (phase_info == (MemoryInfo *) NULL) ||
       (inverse_info == (MemoryInfo *) NULL))
@@ -1175,27 +1176,32 @@ static MagickBooleanType InverseFourier(FourierInfo *fourier_info,
         case RedPixelChannel:
         default:
         {
-          magnitude_pixels[i]=QuantumScale*GetPixelRed(magnitude_image,p);
+          magnitude_pixels[i]=QuantumScale*(double)
+            GetPixelRed(magnitude_image,p);
           break;
         }
         case GreenPixelChannel:
         {
-          magnitude_pixels[i]=QuantumScale*GetPixelGreen(magnitude_image,p);
+          magnitude_pixels[i]=QuantumScale*(double)
+            GetPixelGreen(magnitude_image,p);
           break;
         }
         case BluePixelChannel:
         {
-          magnitude_pixels[i]=QuantumScale*GetPixelBlue(magnitude_image,p);
+          magnitude_pixels[i]=QuantumScale*(double)
+            GetPixelBlue(magnitude_image,p);
           break;
         }
         case BlackPixelChannel:
         {
-          magnitude_pixels[i]=QuantumScale*GetPixelBlack(magnitude_image,p);
+          magnitude_pixels[i]=QuantumScale*(double)
+            GetPixelBlack(magnitude_image,p);
           break;
         }
         case AlphaPixelChannel:
         {
-          magnitude_pixels[i]=QuantumScale*GetPixelAlpha(magnitude_image,p);
+          magnitude_pixels[i]=QuantumScale*(double)
+            GetPixelAlpha(magnitude_image,p);
           break;
         }
       }
@@ -1207,7 +1213,7 @@ static MagickBooleanType InverseFourier(FourierInfo *fourier_info,
   status=InverseQuadrantSwap(fourier_info->width,fourier_info->height,
     magnitude_pixels,inverse_pixels);
   (void) memcpy(magnitude_pixels,inverse_pixels,fourier_info->height*
-    fourier_info->center*sizeof(*magnitude_pixels));
+    (size_t) fourier_info->center*sizeof(*magnitude_pixels));
   i=0L;
   phase_view=AcquireVirtualCacheView(phase_image,exception);
   for (y=0L; y < (ssize_t) fourier_info->height; y++)
@@ -1223,27 +1229,27 @@ static MagickBooleanType InverseFourier(FourierInfo *fourier_info,
         case RedPixelChannel:
         default:
         {
-          phase_pixels[i]=QuantumScale*GetPixelRed(phase_image,p);
+          phase_pixels[i]=QuantumScale*(double) GetPixelRed(phase_image,p);
           break;
         }
         case GreenPixelChannel:
         {
-          phase_pixels[i]=QuantumScale*GetPixelGreen(phase_image,p);
+          phase_pixels[i]=QuantumScale*(double) GetPixelGreen(phase_image,p);
           break;
         }
         case BluePixelChannel:
         {
-          phase_pixels[i]=QuantumScale*GetPixelBlue(phase_image,p);
+          phase_pixels[i]=QuantumScale*(double) GetPixelBlue(phase_image,p);
           break;
         }
         case BlackPixelChannel:
         {
-          phase_pixels[i]=QuantumScale*GetPixelBlack(phase_image,p);
+          phase_pixels[i]=QuantumScale*(double) GetPixelBlack(phase_image,p);
           break;
         }
         case AlphaPixelChannel:
         {
-          phase_pixels[i]=QuantumScale*GetPixelAlpha(phase_image,p);
+          phase_pixels[i]=QuantumScale*(double) GetPixelAlpha(phase_image,p);
           break;
         }
       }
@@ -1268,7 +1274,7 @@ static MagickBooleanType InverseFourier(FourierInfo *fourier_info,
     status=InverseQuadrantSwap(fourier_info->width,fourier_info->height,
       phase_pixels,inverse_pixels);
   (void) memcpy(phase_pixels,inverse_pixels,fourier_info->height*
-    fourier_info->center*sizeof(*phase_pixels));
+    (size_t) fourier_info->center*sizeof(*phase_pixels));
   inverse_info=RelinquishVirtualMemory(inverse_info);
   /*
     Merge two sets.
@@ -1279,7 +1285,7 @@ static MagickBooleanType InverseFourier(FourierInfo *fourier_info,
        for (x=0L; x < (ssize_t) fourier_info->center; x++)
        {
 #if defined(MAGICKCORE_HAVE_COMPLEX_H)
-         fourier_pixels[i]=magnitude_pixels[i]*cos(phase_pixels[i])+I*
+         fourier_pixels[i]=magnitude_pixels[i]*cos(phase_pixels[i])+(double) I*
            magnitude_pixels[i]*sin(phase_pixels[i]);
 #else
          fourier_pixels[i][0]=magnitude_pixels[i]*cos(phase_pixels[i]);
@@ -1292,7 +1298,7 @@ static MagickBooleanType InverseFourier(FourierInfo *fourier_info,
       for (x=0L; x < (ssize_t) fourier_info->center; x++)
       {
 #if defined(MAGICKCORE_HAVE_COMPLEX_H)
-        fourier_pixels[i]=magnitude_pixels[i]+I*phase_pixels[i];
+        fourier_pixels[i]=magnitude_pixels[i]+(double) I*phase_pixels[i];
 #else
         fourier_pixels[i][0]=magnitude_pixels[i];
         fourier_pixels[i][1]=phase_pixels[i];
@@ -1327,13 +1333,20 @@ static MagickBooleanType InverseFourierTransform(FourierInfo *fourier_info,
 
   ssize_t
     i,
-    x;
-
-  ssize_t
+    x,
     y;
 
-  source_info=AcquireVirtualMemory((size_t) fourier_info->width,
-    fourier_info->height*sizeof(*source_pixels));
+  /*
+    Generate the inverse Fourier transform.
+  */
+  if ((fourier_info->width >= INT_MAX) || (fourier_info->height >= INT_MAX))
+    {
+      (void) ThrowMagickException(exception,GetMagickModule(),ImageError,
+        "WidthOrHeightExceedsLimit","`%s'",image->filename);
+      return(MagickFalse);
+    }
+  source_info=AcquireVirtualMemory(fourier_info->width,fourier_info->height*
+    sizeof(*source_pixels));
   if (source_info == (MemoryInfo *) NULL)
     {
       (void) ThrowMagickException(exception,GetMagickModule(),
@@ -1368,8 +1381,8 @@ static MagickBooleanType InverseFourierTransform(FourierInfo *fourier_info,
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
   #pragma omp critical (MagickCore_InverseFourierTransform)
 #endif
-  fftw_c2r_plan=fftw_plan_dft_c2r_2d(fourier_info->width,fourier_info->height,
-    fourier_pixels,source_pixels,FFTW_ESTIMATE);
+  fftw_c2r_plan=fftw_plan_dft_c2r_2d((int) fourier_info->width,
+    (int) fourier_info->height,fourier_pixels,source_pixels,FFTW_ESTIMATE);
   fftw_execute_dft_c2r(fftw_c2r_plan,fourier_pixels,source_pixels);
   fftw_destroy_plan(fftw_c2r_plan);
   i=0L;
@@ -1390,31 +1403,32 @@ static MagickBooleanType InverseFourierTransform(FourierInfo *fourier_info,
           case RedPixelChannel:
           default:
           {
-            SetPixelRed(image,ClampToQuantum(QuantumRange*source_pixels[i]),q);
+            SetPixelRed(image,ClampToQuantum((double) QuantumRange*
+              source_pixels[i]),q);
             break;
           }
           case GreenPixelChannel:
           {
-            SetPixelGreen(image,ClampToQuantum(QuantumRange*source_pixels[i]),
-              q);
+            SetPixelGreen(image,ClampToQuantum((double) QuantumRange*
+              source_pixels[i]),q);
             break;
           }
           case BluePixelChannel:
           {
-            SetPixelBlue(image,ClampToQuantum(QuantumRange*source_pixels[i]),
-              q);
+            SetPixelBlue(image,ClampToQuantum((double) QuantumRange*
+              source_pixels[i]),q);
             break;
           }
           case BlackPixelChannel:
           {
-            SetPixelBlack(image,ClampToQuantum(QuantumRange*source_pixels[i]),
-              q);
+            SetPixelBlack(image,ClampToQuantum((double) QuantumRange*
+              source_pixels[i]),q);
             break;
           }
           case AlphaPixelChannel:
           {
-            SetPixelAlpha(image,ClampToQuantum(QuantumRange*source_pixels[i]),
-              q);
+            SetPixelAlpha(image,ClampToQuantum((double) QuantumRange*
+              source_pixels[i]),q);
             break;
           }
         }
@@ -1460,8 +1474,8 @@ static MagickBooleanType InverseFourierTransformChannel(
   fourier_info.center=(ssize_t) (fourier_info.width/2L)+1L;
   fourier_info.channel=channel;
   fourier_info.modulus=modulus;
-  inverse_info=AcquireVirtualMemory((size_t) fourier_info.width,
-    (fourier_info.height/2+1)*sizeof(*inverse_pixels));
+  inverse_info=AcquireVirtualMemory(fourier_info.width,(fourier_info.height/2+
+    1)*sizeof(*inverse_pixels));
   if (inverse_info == (MemoryInfo *) NULL)
     {
       (void) ThrowMagickException(exception,GetMagickModule(),
@@ -1489,7 +1503,7 @@ MagickExport Image *InverseFourierTransformImage(const Image *magnitude_image,
 
   assert(magnitude_image != (Image *) NULL);
   assert(magnitude_image->signature == MagickCoreSignature);
-  if (magnitude_image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       magnitude_image->filename);
   if (phase_image == (Image *) NULL)
@@ -1498,7 +1512,7 @@ MagickExport Image *InverseFourierTransformImage(const Image *magnitude_image,
         "ImageSequenceRequired","`%s'",magnitude_image->filename);
       return((Image *) NULL);
     }
-#if !defined(MAGICKCORE_FFTW_DELEGATE)
+#if !defined(MAGICKCORE_FFTW_DELEGATE) || defined(__cplusplus) || defined(c_plusplus)
   fourier_image=(Image *) NULL;
   (void) modulus;
   (void) ThrowMagickException(exception,GetMagickModule(),
