@@ -223,8 +223,8 @@ static LinkedListInfo *AcquireMagicList(ExceptionInfo *exception)
     magic_info->length=p->length;
     magic_info->skip_spaces=p->skip_spaces;
     magic_info->signature=MagickCoreSignature;
-    status&=InsertValueInSortedLinkedList(list,CompareMagickInfoExtent,
-      NULL,magic_info);
+    status&=(MagickStatusType) InsertValueInSortedLinkedList(list,
+      CompareMagickInfoExtent,NULL,magic_info);
     if (status == MagickFalse)
       (void) ThrowMagickException(exception,GetMagickModule(),
         ResourceLimitError,"MemoryAllocationFailed","`%s'",magic_info->name);
@@ -472,7 +472,7 @@ static int MagicInfoCompare(const void *x,const void *y)
 #endif
 
 MagickExport const MagicInfo **GetMagicInfoList(const char *pattern,
-  size_t *number_aliases,ExceptionInfo *exception)
+  size_t *number_aliases,ExceptionInfo *magick_unused(exception))
 {
   const MagicInfo
     **aliases;
@@ -483,12 +483,13 @@ MagickExport const MagicInfo **GetMagicInfoList(const char *pattern,
   ssize_t
     i;
 
+  magick_unreferenced(exception);
   assert(pattern != (char *) NULL);
   assert(number_aliases != (size_t *) NULL);
   if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",pattern);
   *number_aliases=0;
-  if (IsMagicCacheInstantiated(exception) == MagickFalse)
+  if (IsMagicCacheInstantiated() == MagickFalse)
     return((const MagicInfo **) NULL);
   aliases=(const MagicInfo **) AcquireQuantumMemory((size_t)
     GetNumberOfElementsInLinkedList(magic_list)+1UL,sizeof(*aliases));
@@ -508,7 +509,7 @@ MagickExport const MagicInfo **GetMagicInfoList(const char *pattern,
   }
   UnlockSemaphoreInfo(magic_list_semaphore);
   if (i == 0)
-    aliases=(const MagicInfo **) RelinquishMagickMemory(aliases);
+    aliases=(const MagicInfo **) RelinquishMagickMemory((void*) aliases);
   else
     {
       qsort((void *) aliases,(size_t) i,sizeof(*aliases),MagicInfoCompare);
@@ -568,7 +569,7 @@ static int MagicCompare(const void *x,const void *y)
 #endif
 
 MagickExport char **GetMagicList(const char *pattern,size_t *number_aliases,
-  ExceptionInfo *exception)
+  ExceptionInfo *magick_unused(exception))
 {
   char
     **aliases;
@@ -578,13 +579,14 @@ MagickExport char **GetMagicList(const char *pattern,size_t *number_aliases,
 
   ssize_t
     i;
-
+  
+  magick_unreferenced(exception);
   assert(pattern != (char *) NULL);
   assert(number_aliases != (size_t *) NULL);
   if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",pattern);
   *number_aliases=0;
-  if (IsMagicCacheInstantiated(exception) == MagickFalse)
+  if (IsMagicCacheInstantiated() == MagickFalse)
     return((char **) NULL);
   aliases=(char **) AcquireQuantumMemory((size_t)
     GetNumberOfElementsInLinkedList(magic_list)+1UL,sizeof(*aliases));
