@@ -17,7 +17,7 @@
 %                                 July 1998                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright @ 1999 ImageMagick Studio LLC, a non-profit organization         %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -771,7 +771,7 @@ MagickExport MemoryInfo *AcquireVirtualMemory(const size_t count,
               MagickOffsetType
                 offset;
 
-              offset=(MagickOffsetType) lseek(file,size-1,SEEK_SET);
+              offset=(MagickOffsetType) lseek(file,(off_t) (size-1),SEEK_SET);
               if ((offset == (MagickOffsetType) (size-1)) &&
                   (write(file,"",1) == 1))
                 {
@@ -851,14 +851,14 @@ MagickExport void *CopyMagickMemory(void *magick_restrict destination,
     switch (size)
     {
       default: return(memcpy(destination,source,size));
-      case 8: *q++=(*p++);
-      case 7: *q++=(*p++);
-      case 6: *q++=(*p++);
-      case 5: *q++=(*p++);
-      case 4: *q++=(*p++);
-      case 3: *q++=(*p++);
-      case 2: *q++=(*p++);
-      case 1: *q++=(*p++);
+      case 8: *q++=(*p++); magick_fallthrough;
+      case 7: *q++=(*p++); magick_fallthrough;
+      case 6: *q++=(*p++); magick_fallthrough;
+      case 5: *q++=(*p++); magick_fallthrough;
+      case 4: *q++=(*p++); magick_fallthrough;
+      case 3: *q++=(*p++); magick_fallthrough;
+      case 2: *q++=(*p++); magick_fallthrough;
+      case 1: *q++=(*p++); magick_fallthrough;
       case 0: return(destination);
     }
   return(memmove(destination,source,size));
@@ -1050,7 +1050,7 @@ MagickExport size_t GetMaxMemoryRequest(void)
       char
         *value;
 
-      max_memory_request=MAGICK_SSIZE_MAX;
+      max_memory_request=(size_t) MAGICK_SSIZE_MAX;
       value=GetPolicyValue("system:max-memory-request");
       if (value != (char *) NULL)
         {
@@ -1062,7 +1062,7 @@ MagickExport size_t GetMaxMemoryRequest(void)
           value=DestroyString(value);
         }
     }
-  return(MagickMin(max_memory_request,MAGICK_SSIZE_MAX));
+  return(MagickMin(max_memory_request,(size_t) MAGICK_SSIZE_MAX));
 }
 
 /*
@@ -1235,6 +1235,7 @@ MagickExport MemoryInfo *RelinquishVirtualMemory(MemoryInfo *memory_info)
     {
       case AlignedVirtualMemory:
       {
+        (void) ShredMagickMemory(memory_info->blob,memory_info->length);
         memory_info->blob=RelinquishAlignedMemory(memory_info->blob);
         break;
       }
@@ -1249,6 +1250,7 @@ MagickExport MemoryInfo *RelinquishVirtualMemory(MemoryInfo *memory_info)
       case UnalignedVirtualMemory:
       default:
       {
+        (void) ShredMagickMemory(memory_info->blob,memory_info->length);
         memory_info->blob=RelinquishMagickMemory(memory_info->blob);
         break;
       }
@@ -1551,3 +1553,100 @@ MagickExport void SetMagickMemoryMethods(
   if (destroy_memory_handler != (DestroyMemoryHandler) NULL)
     memory_methods.destroy_memory_handler=destroy_memory_handler;
 }
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   S h r e d M a g i c k M e m o r y                                         %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  ShredMagickMemory() overwrites the specified memory buffer with random data.
+%  The overwrite is optional and is only required to help keep the contents of
+%  the memory buffer private.
+%
+%  The format of the ShredMagickMemory method is:
+%
+%      MagickBooleanType ShredMagickMemory(void *memory,const size_t length)
+%
+%  A description of each parameter follows.
+%
+%    o memory:  Specifies the memory buffer.
+%
+%    o length:  Specifies the length of the memory buffer.
+%
+*/
+MagickPrivate MagickBooleanType ShredMagickMemory(void *memory,
+  const size_t length)
+{
+  RandomInfo
+    *random_info;
+
+  size_t
+    quantum;
+
+  ssize_t
+    i;
+
+  static ssize_t
+    passes = -1;
+
+  StringInfo
+    *key;
+
+  if ((memory == NULL) || (length == 0))
+    return(MagickFalse);
+  if (passes == -1)
+    {
+      char
+        *property;
+
+      passes=0;
+      property=GetEnvironmentValue("MAGICK_SHRED_PASSES");
+      if (property != (char *) NULL)
+        {
+          passes=(ssize_t) StringToInteger(property);
+          property=DestroyString(property);
+        }
+      property=GetPolicyValue("system:shred");
+      if (property != (char *) NULL)
+        {
+          passes=(ssize_t) StringToInteger(property);
+          property=DestroyString(property);
+        }
+    }
+  if (passes == 0)
+    return(MagickTrue);
+  /*
+    Overwrite the memory buffer with random data.
+  */
+  quantum=(size_t) MagickMin(length,MagickMinBufferExtent);
+  random_info=AcquireRandomInfo();
+  key=GetRandomKey(random_info,quantum);
+  for (i=0; i < passes; i++)
+  {
+    size_t
+      j;
+
+    unsigned char
+      *p = (unsigned char *) memory;
+
+    for (j=0; j < length; j+=quantum)
+    {
+      if (i != 0)
+        SetRandomKey(random_info,quantum,GetStringInfoDatum(key));
+      (void) memcpy(p,GetStringInfoDatum(key),(size_t)
+        MagickMin(quantum,length-j));
+      p+=quantum;
+    }
+    if (j < length)
+      break;
+  }
+  key=DestroyStringInfo(key);
+  random_info=DestroyRandomInfo(random_info);
+  return(i < passes ? MagickFalse : MagickTrue);
+}
