@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright @ 1999 ImageMagick Studio LLC, a non-profit organization         %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -136,7 +136,7 @@ typedef struct _IconInfo
 } IconInfo;
 
 /*
-  Forward declaractions.
+  Forward declarations.
 */
 static MagickBooleanType
   WriteICONImage(const ImageInfo *,Image *,ExceptionInfo *);
@@ -223,6 +223,7 @@ static Image *ReadICONImage(const ImageInfo *image_info,
       image=DestroyImageList(image);
       return((Image *) NULL);
     }
+  (void) memset(&icon_file,0,sizeof(icon_file));
   icon_file.reserved=(short) ReadBlobLSBShort(image);
   icon_file.resource_type=(short) ReadBlobLSBShort(image);
   icon_file.count=(short) ReadBlobLSBShort(image);
@@ -415,11 +416,11 @@ static Image *ReadICONImage(const ImageInfo *image_info,
         status=SetImageExtent(image,image->columns,image->rows,exception);
         if (status == MagickFalse)
           return(DestroyImageList(image));
-        bytes_per_line=(((image->columns*icon_info.bits_per_pixel)+31) &
-          ~31) >> 3;
+        bytes_per_line=(((image->columns*icon_info.bits_per_pixel)+31U) &
+          ~31U) >> 3;
         (void) bytes_per_line;
-        scanline_pad=((((image->columns*icon_info.bits_per_pixel)+31) & ~31)-
-          (image->columns*icon_info.bits_per_pixel)) >> 3;
+        scanline_pad=((((image->columns*icon_info.bits_per_pixel)+31U) &
+          ~31U)-(image->columns*icon_info.bits_per_pixel)) >> 3;
         switch (icon_info.bits_per_pixel)
         {
           case 1:
@@ -458,8 +459,8 @@ static Image *ReadICONImage(const ImageInfo *image_info,
                 break;
               if (image->previous == (Image *) NULL)
                 {
-                  status=SetImageProgress(image,LoadImageTag,image->rows-y-1,
-                    image->rows);
+                  status=SetImageProgress(image,LoadImageTag,(MagickOffsetType)
+                    image->rows-y-1,(MagickSizeType) image->rows);
                   if (status == MagickFalse)
                     break;
                 }
@@ -496,8 +497,8 @@ static Image *ReadICONImage(const ImageInfo *image_info,
                 break;
               if (image->previous == (Image *) NULL)
                 {
-                  status=SetImageProgress(image,LoadImageTag,image->rows-y-1,
-                    image->rows);
+                  status=SetImageProgress(image,LoadImageTag,(MagickOffsetType)
+                    image->rows-y-1,(MagickSizeType) image->rows);
                   if (status == MagickFalse)
                     break;
                 }
@@ -526,8 +527,8 @@ static Image *ReadICONImage(const ImageInfo *image_info,
                 break;
               if (image->previous == (Image *) NULL)
                 {
-                  status=SetImageProgress(image,LoadImageTag,image->rows-y-1,
-                    image->rows);
+                  status=SetImageProgress(image,LoadImageTag,(MagickOffsetType)
+                    image->rows-y-1,(MagickSizeType) image->rows);
                   if (status == MagickFalse)
                     break;
                 }
@@ -557,8 +558,8 @@ static Image *ReadICONImage(const ImageInfo *image_info,
                 break;
               if (image->previous == (Image *) NULL)
                 {
-                  status=SetImageProgress(image,LoadImageTag,image->rows-y-1,
-                    image->rows);
+                  status=SetImageProgress(image,LoadImageTag,(MagickOffsetType)
+                    image->rows-y-1,(MagickSizeType) image->rows);
                   if (status == MagickFalse)
                     break;
                 }
@@ -596,8 +597,8 @@ static Image *ReadICONImage(const ImageInfo *image_info,
                 break;
               if (image->previous == (Image *) NULL)
                 {
-                  status=SetImageProgress(image,LoadImageTag,image->rows-y-1,
-                    image->rows);
+                  status=SetImageProgress(image,LoadImageTag,(MagickOffsetType)
+                    image->rows-y-1,(MagickSizeType) image->rows);
                   if (status == MagickFalse)
                     break;
                 }
@@ -858,6 +859,9 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
   const char
     *option;
 
+  const Quantum
+    *p;
+
   IconFile
     icon_file;
 
@@ -869,32 +873,26 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
     *next;
   
   MagickBooleanType
+    adjoin,
     status;
 
   MagickOffsetType
     offset,
     scene;
 
-  const Quantum
-    *p;
-
-  ssize_t
-    i,
-    x;
-
-  unsigned char
-    *q;
-
   size_t
     bytes_per_line,
-    imageListLength,
+    number_scenes,
     scanline_pad;
 
   ssize_t
+    i,
+    x,
     y;
 
   unsigned char
-    *pixels;
+    *pixels,
+    *q;
 
   /*
     Open output image file.
@@ -910,12 +908,14 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
   if (status == MagickFalse)
     return(status);
   images=(Image *) NULL;
+  adjoin=image_info->adjoin;
   option=GetImageOption(image_info,"icon:auto-resize");
   if (option != (const char *) NULL)
     {
       images=AutoResizeImage(image,option,&scene,exception);
       if (images == (Image *) NULL)
         ThrowWriterException(ImageError,"InvalidDimensions");
+      adjoin=MagickTrue;
     }
   else
     {
@@ -927,7 +927,7 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
           ThrowWriterException(ImageError,"WidthOrHeightExceedsLimit");
         scene++;
         next=SyncNextImageInList(next);
-      } while ((next != (Image *) NULL) && (image_info->adjoin != MagickFalse));
+      } while ((next != (Image *) NULL) && (adjoin != MagickFalse));
     }
   /*
     Dump out a ICON header template to be properly initialized later.
@@ -953,10 +953,10 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
       icon_file.directory[scene].offset);
     scene++;
     next=SyncNextImageInList(next);
-  } while ((next != (Image *) NULL) && (image_info->adjoin != MagickFalse));
+  } while ((next != (Image *) NULL) && (adjoin != MagickFalse));
   scene=0;
   next=(images != (Image *) NULL) ? images : image;
-  imageListLength=GetImageListLength(image);
+  number_scenes=GetImageListLength(image);
   do
   {
     if ((next->columns > 255L) && (next->rows > 255L) &&
@@ -1064,8 +1064,8 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
                 icon_info.offset_bits+=(one << icon_info.bits_per_pixel);
               }
           }
-        bytes_per_line=(((next->columns*icon_info.bits_per_pixel)+31) & ~31) >>
-          3;
+        bytes_per_line=(((next->columns*icon_info.bits_per_pixel)+31U) &
+          ~31U) >> 3;
         icon_info.ba_offset=0;
         icon_info.width=(ssize_t) next->columns;
         icon_info.height=(ssize_t) next->rows;
@@ -1074,7 +1074,8 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
         icon_info.size=40;
         icon_info.size+=(4*icon_info.number_colors);
         icon_info.size+=icon_info.image_size;
-        icon_info.size+=(((icon_info.width+31) & ~31) >> 3)*icon_info.height;
+        icon_info.size+=(size_t) ((((icon_info.width+31U) & ~31U) >> 3)*
+          icon_info.height);
         icon_info.file_size+=icon_info.image_size;
         icon_info.x_pixels=0;
         icon_info.y_pixels=0;
@@ -1122,13 +1123,13 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
               p=GetVirtualPixels(next,0,y,next->columns,1,exception);
               if (p == (const Quantum *) NULL)
                 break;
-              q=pixels+(next->rows-y-1)*bytes_per_line;
+              q=pixels+((ssize_t) next->rows-y-1)*(ssize_t) bytes_per_line;
               bit=0;
               byte=0;
               for (x=0; x < (ssize_t) next->columns; x++)
               {
                 byte<<=1;
-                byte|=GetPixelIndex(next,p) != 0 ? 0x01 : 0x00;
+                byte|=(size_t) (GetPixelIndex(next,p) != 0 ? 0x01 : 0x00);
                 bit++;
                 if (bit == 8)
                   {
@@ -1163,7 +1164,7 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
               p=GetVirtualPixels(next,0,y,next->columns,1,exception);
               if (p == (const Quantum *) NULL)
                 break;
-              q=pixels+(next->rows-y-1)*bytes_per_line;
+              q=pixels+((ssize_t) next->rows-y-1)*(ssize_t) bytes_per_line;
               nibble=0;
               byte=0;
               for (x=0; x < (ssize_t) next->columns; x++)
@@ -1200,7 +1201,7 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
               p=GetVirtualPixels(next,0,y,next->columns,1,exception);
               if (p == (const Quantum *) NULL)
                 break;
-              q=pixels+(next->rows-y-1)*bytes_per_line;
+              q=pixels+((ssize_t) next->rows-y-1)*(ssize_t) bytes_per_line;
               for (x=0; x < (ssize_t) next->columns; x++)
               {
                 *q++=(unsigned char) GetPixelIndex(next,p);
@@ -1226,7 +1227,7 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
               p=GetVirtualPixels(next,0,y,next->columns,1,exception);
               if (p == (const Quantum *) NULL)
                 break;
-              q=pixels+(next->rows-y-1)*bytes_per_line;
+              q=pixels+((ssize_t) next->rows-y-1)*(ssize_t) bytes_per_line;
               for (x=0; x < (ssize_t) next->columns; x++)
               {
                 *q++=ScaleQuantumToChar(GetPixelBlue(next,p));
@@ -1283,8 +1284,8 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
             /*
               Dump colormap to file.
             */
-            icon_colormap=(unsigned char *) AcquireQuantumMemory((size_t)
-              (1UL << icon_info.bits_per_pixel),4UL*sizeof(*icon_colormap));
+            icon_colormap=(unsigned char *) AcquireQuantumMemory((size_t) 1UL
+              << icon_info.bits_per_pixel,4UL*sizeof(*icon_colormap));
             if (icon_colormap == (unsigned char *) NULL)
               {
                 images=DestroyImageList(images);
@@ -1299,7 +1300,7 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
               *q++=ScaleQuantumToChar(next->colormap[i].red);
               *q++=(unsigned char) 0x0;
             }
-            for ( ; i < (ssize_t) (1UL << icon_info.bits_per_pixel); i++)
+            for ( ; i < (ssize_t) 1UL << icon_info.bits_per_pixel; i++)
             {
               *q++=(unsigned char) 0x00;
               *q++=(unsigned char) 0x00;
@@ -1316,7 +1317,7 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
         /*
           Write matte mask.
         */
-        scanline_pad=(((next->columns+31) & ~31)-next->columns) >> 3;
+        scanline_pad=(((next->columns+31U) & ~31U)-next->columns) >> 3;
         for (y=((ssize_t) next->rows - 1); y >= 0; y--)
         {
           unsigned char
@@ -1351,11 +1352,11 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
       }
     if (GetNextImageInList(next) == (Image *) NULL)
       break;
-    status=SetImageProgress(next,SaveImagesTag,scene++,imageListLength);
+    status=SetImageProgress(next,SaveImagesTag,scene++,number_scenes);
     if (status == MagickFalse)
       break;
     next=SyncNextImageInList(next);
-  } while ((next != (Image *) NULL) && (image_info->adjoin != MagickFalse));
+  } while ((next != (Image *) NULL) && (adjoin != MagickFalse));
   offset=SeekBlob(image,0,SEEK_SET);
   (void) offset;
   (void) WriteBlobLSBShort(image,0);
@@ -1377,7 +1378,7 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
       icon_file.directory[scene].offset);
     scene++;
     next=SyncNextImageInList(next);
-  } while ((next != (Image *) NULL) && (image_info->adjoin != MagickFalse));
+  } while ((next != (Image *) NULL) && (adjoin != MagickFalse));
   (void) CloseBlob(image);
   images=DestroyImageList(images);
   return(MagickTrue);
